<?php
/**
 * @file
 * media_theplatform_mpx/includes/media_theplatform_mpx.formatters.inc
 *
 * Define Media:mpx formatters.
 */

/**
 * Implements hook_file_formatter_info().
 */
function media_theplatform_mpx_file_formatter_info() {
  $formatters['media_theplatform_mpx_video'] = array(
    'label' => t('mpx Video'),
    'file types' => array('video'),
    'view callback' => 'media_theplatform_mpx_file_formatter_video_view',
    'settings callback' => 'media_theplatform_mpx_file_formatter_video_settings',
  );
  $formatters['media_theplatform_mpx_image'] = array(
    'label' => t('mpx Preview Image'),
    'file types' => array('video'),
    'default settings' => array(
      'image_style' => '',
    ),
    'view callback' => 'media_theplatform_mpx_file_formatter_image_view',
    'settings callback' => 'media_theplatform_mpx_file_formatter_image_settings',
  );
  return $formatters;
}

/**
 * Implements hook_file_formatter_FORMATTER_view().
 */
function media_theplatform_mpx_file_formatter_video_view($file, $display, $langcode) {
  $scheme = file_uri_scheme($file->uri);
  // WYSIWYG does not yet support video inside a running editor instance.
  if ($scheme == 'mpx' && empty($file->override['wysiwyg'])) {
    $element = array(
      '#theme' => 'media_theplatform_mpx_video',
      '#uri' => $file->uri,
    );
    return $element;
  }
}

/**
 * Implements hook_file_formatter_FORMATTER_settings().
 */
function media_theplatform_mpx_file_formatter_video_settings($form, &$form_state, $settings) {
  $element = array();
  // We don't customize anything in Drupal, its all via thePlatform.
  $element['info'] = array(
    '#markup' => t('All mpxPlayer display settings are configured through your account on thePlatform and imported upon Sync.'),
  );
  return $element;
}

/**
 * Implements hook_file_formatter_FORMATTER_view().
 */
function media_theplatform_mpx_file_formatter_image_view($file, $display, $langcode) {
  $scheme = file_uri_scheme($file->uri);
  if ($scheme == 'mpx') {
    $wrapper = file_stream_wrapper_get_instance_by_uri($file->uri);
    $parts = $wrapper->get_parameters();

    $image_style = $display['settings']['image_style'];
    $valid_image_styles = image_style_options(FALSE);

    if (empty($image_style) || !isset($valid_image_styles[$image_style])) {
      $element = array(
        '#theme' => 'image',
        '#path' => $wrapper->getOriginalThumbnailPath(),
      );
    }
    else {
      $element = array(
        '#theme' => 'image_style',
        '#style_name' => $image_style,
        '#path' => $wrapper->getLocalThumbnailPath(),
      );
    }
    return $element;
  }
}

/**
 * Implements hook_file_formatter_FORMATTER_settings().
 */
function media_theplatform_mpx_file_formatter_image_settings($form, &$form_state, $settings) {
  $element = array();
  $element['image_style'] = array(
    '#title' => t('Image style'),
    '#type' => 'select',
    '#options' => image_style_options(FALSE),
    '#default_value' => $settings['image_style'],
    '#empty_option' => t('None (original image)'),
  );
  return $element;
}

/**
 * Implements hook_file_default_displays().
 */
function media_theplatform_mpx_file_default_displays() {
  $default_displays = array();

  // Default settings for displaying as a video.
  $default_video_settings = array(
    // Must include media_large for this to work.
    'media_large' => array(),
    'media_original' => array(),
  );

  foreach ($default_video_settings as $view_mode => $settings) {
    $display_name = 'video__' . $view_mode . '__media_theplatform_mpx_video';
    $default_displays[$display_name] = (object) array(
      'api_version' => 1,
      'name' => $display_name,
      'status' => 1,
      'weight' => 1,
      'settings' => $settings,
    );
  }

  // Default settings for displaying a video preview image. We enable preview
  // images even for view modes that also play video, for use inside a running
  // WYSIWYG editor. The higher weight ensures that the video display is used
  // where possible.
  $default_image_styles = array(
    'media_preview' => 'square_thumbnail',
    'media_large' => 'large',
    'media_original' => '',
  );
  foreach ($default_image_styles as $view_mode => $image_style) {
    $display_name = 'video__' . $view_mode . '__media_theplatform_mpx_image';
    $default_displays[$display_name] = (object) array(
      'api_version' => 1,
      'name' => $display_name,
      'status' => 1,
      'weight' => 2,
      'settings' => array('image_style' => $image_style),
    );
  }

  return $default_displays;
}


/**
 * Implements hook_field_formatter_info().
 *
 * Adds the Galleria format option within the manage display form of
 * of an image field.
 */
function media_theplatform_mpx_field_formatter_info() {
  return array(
    'mpx' => array(
      'label' => t('MPX Media'),
      'field types' => array('file'),
      'settings' => array(
        'player' => '',
        'width' => '355',
        'height' => '200',
        'image_style' => '',
      ),
    ),
  );
}



function media_theplatform_mpx_field_formatter_settings_form($field, $instance, $view_mode, $form, &$form_state) {
  //This gets the view_mode where our settings are stored
  $display = $instance['display'][$view_mode];
  //This gets the actual settings
  $settings = $display['settings'];
  //Initialize the element variable
  $element = array();

  $players = media_theplatform_mpx_get_players();
  $options = array();
  foreach ($players as $player) {
    $options[$player->fid] = $player->title;
  }
  $options['image'] = t('Thumbnail');

  $element['player'] = array(
    '#type'           => 'select',
    '#title'          => t('Player'),
    '#description'    => t('Select what MPX player renders this media'),
    '#default_value'  => $settings['player'],
    '#options'        => $options,
  );
  $element['width'] = array(
    '#type'           => 'textfield',
    '#title'          => t('Width'),
    '#default_value'  => $settings['width'],
    '#states' => array(
      'invisible' => array(
        ':input[name="options[settings][player]"]' => array(
          'value' => 'image',
        ),
      ),
    ),
  );
  $element['height'] = array(
    '#type'           => 'textfield',
    '#title'          => t('Height'),
    '#default_value'  => $settings['height'],
    '#states' => array(
      'invisible' => array(
        ':input[name="options[settings][player]"]' => array(
          'value' => 'image',
        ),
      ),
    ),
  );
  $element['image_style'] = array(
    '#title' => t('Image style'),
    '#type' => 'select',
    '#options' => image_style_options(FALSE),
    '#default_value' => $settings['image_style'],
    '#empty_option' => t('None (original image)'),
    '#states' => array(
      'visible' => array(
        ':input[name="options[settings][player]"]' => array(
          'value' => 'image',
        ),
      ),
    ),
  );
  return $element;
}

function media_theplatform_mpx_field_formatter_settings_summary($field, $instance, $view_mode) {
  $display = $instance['display'][$view_mode];
  $settings = $display['settings'];
  $summary = t('Use a @width x @height MPX Player - @player', array(
    '@player'     => $settings['player'],
    '@width'  => $settings['width'],
    '@height'  => $settings['height'],
  ));
  return $summary;
}

/**
 * Implements hook_field_formatter_view().
 */
function media_theplatform_mpx_field_formatter_view($entity_type, $entity, $field, $instance, $langcode, $items, $display) {

  $element = array();
  $settings = $display['settings'];
  $player = $settings['player'];
  $width = $settings['width'];
  $height = $settings['height'];
  $mpx_player = media_theplatform_mpx_get_mpx_player_by_fid($player);
  if (!empty($entity->{$field['field_name']})){
    $uri = $entity->{$field['field_name']}[$entity->language][0]['uri'];
    $wrapper = file_stream_wrapper_get_instance_by_uri($uri);
    $parts = $wrapper->get_parameters();
  } else {
    return;
  }
  if ($player != 'image' && isset($mpx_player)) {
    $body = media_theplatform_mpx_add_guid_to_html($parts['mpx_id'], $mpx_player['body_html']);
    $body = media_theplatform_mpx_replace_html_ids($body, $parts['mpx_id']);
    $element = array(
      '#theme' => 'media_theplatform_mpx_video',
      '#uri' => $uri . '/' . $player,
      '#width' => $width,
      '#height' => $height,
    );
    $body = drupal_render($element);

    $player_data = media_theplatform_mpx_get_player_data($mpx_player);
    // Replace css selectors with #mpx_id selectors.
    $player_css = media_theplatform_mpx_replace_css_ids($player_data['css'], $parts['mpx_id']);
    // Add mpxPlayer CSS.
    drupal_add_css($player_css, 'inline');

    // Add mpxPlayer inline JS.
    if (isset($player_data['js']['inline'])) {
      foreach ($player_data['js']['inline'] as $script) {
        drupal_add_js($script, 'inline');
      }
    }
    // Add mpxPlayer external JS files.
    if (isset($player_data['js']['external'])) {
      foreach ($player_data['js']['external'] as $src) {
        drupal_add_js($src, 'external');
      }
    }
    $element[0]['#markup'] = $body;
  } else if ($player == 'image') {
    // grab the image for this mpx media.
    $wrapper = file_stream_wrapper_get_instance_by_uri($uri);
    $parts = $wrapper->get_parameters();

    $image_style = $settings['image_style'];
    $valid_image_styles = image_style_options(FALSE);

    if (empty($image_style) || !isset($valid_image_styles[$image_style])) {
      $element = array(
        '#theme' => 'image',
        '#path' => $wrapper->getOriginalThumbnailPath(),
      );
    }
    else {
      $element[0] = array(
        '#theme' => 'image_style',
        '#style_name' => $image_style,
        '#path' => $wrapper->getLocalThumbnailPath(),
      );
    }
  } else {
     $element[0]['#markup'] = t('No MPX Player selected');
  }

  return $element;
}