/**
 * @file
 * Handles the JS for the views file browser. Note that this does not currently
 * support multiple file selection
 */


(function ($) {

  Drupal.behaviors.mediaMpxBrowser = {
    attach: function (context, settings) {
      // media_browser_library_list container
      var $media_browser_library_list = $('ul#media-browser-library-list.videos-browser');
      var current_page = 0,
          items_per_page;

      // mpxMediaHandler does media-item click detection
      // and handles form input to media entity binding.
      var mpxMediaHandler = function() {
        // Remove all currently selected files
        $('.media-item').removeClass('selected');
        // Set the current item to active
        $(this).addClass('selected');
        // Add this FID to the array of selected files
        var uri = $(this).parent().parent('a[data-uri]').attr('data-uri');
        // Get the file from the settings which was stored in
        // template_preprocess_media_views_view_media_browser()
        var file = Drupal.settings.media.files[uri];
        var files = [];
        files.push(file);
        Drupal.media.browser.selectMedia(files);
        $("input[name='selected_file']").val(uri);
      };

      // generatePages takes an array of items as an argument
      // or Drupal.settings.videos.form_list if no arguments
      // and creates a paged array with each page containing up to items_per_page items.
      // items_per_page is defined in a scope above generatePages and can be modified
      // prior to calling generatePages.
      // In adition, every time generatePages is called, current_page (defined in a scope above) is reset to 0.
      var generatePages = function(items) {
        var page = 0,
            slice_start,
            slice_end;

        current_page = 0;
        items = items ? items : Drupal.settings.videos.form_list;
        items_per_page = parseInt(items_per_page, 10) || 100; // Default to 100 items per page.
        Drupal.settings.videos.form_list_paginated = []; // Start from scratch.

        while (true) {
          slice_start = (page) * items_per_page;
          slice_end = (page + 1) * items_per_page;
          var renderable_items = items.slice(slice_start, slice_end);

          if (renderable_items.length) {
            Drupal.settings.videos.form_list_paginated.push(renderable_items);
          } else {
            break;
          }

          ++page;
        }
      };

      // getPage fetches items for a given page, checks the bounds, resets scroll
      // and displays/hides previous/next links as needed.
      var getPage = function(page) {
        var page_items = [],
            form_list_paginated = [];

        // Default to page #0 and/or parse to int.
        current_page = page = (page) ? parseInt(page, 10) : 0;
        if (Drupal.settings.videos != null && Drupal.settings.videos.hasOwnProperty('form_list_paginated') && !isNaN(page)) {
          if (Drupal.settings.videos.form_list_paginated instanceof Array) {
            form_list_paginated = Drupal.settings.videos.form_list_paginated;
            // Page bounds check.
            current_page = page = (page >= form_list_paginated.length) ? (form_list_paginated.length - 1) : page;
            current_page = page = (page < 0) ? 0 : page; // If page is less than 0, reset to 0.
            if (form_list_paginated[page]) {
              page_items = form_list_paginated[page];
            }
          }
        }

        // If we are on a page 0 or below, hide prevous page link.
        // Otherwise display it.
        if (current_page <= 0) {
          $('#mpx-previous a').hide();
        } else {
          $('#mpx-previous a').show();
        }

        // If we are on a last page or above, hide next page link.
        // Otherwise display it.
        if (current_page >= (form_list_paginated.length - 1)) {
          $('#mpx-next a').hide();
        } else {
          $('#mpx-next a').show();
        }

        // Reset scroll box to the top.
        $('#scrollbox').scrollTop(0);

        return page_items;
      };

      // populateList populates list of media-items for given page.
      // In addition, it makes that newly created dom elements have proper bindings.
      var populateList = function(page) {
        var page_items,
            html_list = '';

        if (Drupal.settings.videos.hasOwnProperty('form_list') && !Drupal.settings.videos.hasOwnProperty('form_list_paginated')) {
          generatePages();
        }

        page_items = getPage(page);

        if (page_items.length) {
          for (var i = 0; i < page_items.length; ++i) {
            var page_item = page_items[i];
            html_list += page_item['#prefix'];
            html_list += page_item['#markup'];
            html_list += page_item['#suffix'];
          }
        }

        $media_browser_library_list.html(html_list);
        // Disable the links on media items list
        $('ul#media-browser-library-list a').click(function() {
          return false;
        });

        $('.videos-browser .media-item').bind('click', function () {
          $("input[name='mpx_type']").val('videos');
          // Hide all player selects.
          $('div.mpxplayer_select').hide();
          // Display player select for this Video's account.
          var account = $(this).closest('span').attr('class');
          $('div.'+account).show();
        });

        // Catch the click on a media item
        $('.videos-browser .media-item').bind('click.HandleSelection', mpxMediaHandler);
      };

      $('div.mpxplayer_select').hide();

      // Update hidden value for mpx type.
      $('.players-browser .media-item').bind('click', function () {
        $("input[name='mpx_type']").val('players');
        // Hide player selects on video-browser if we clicked on a mpxPlayer item.
        $('div.mpxplayer_select').hide();
      });

      // Catch the click on a media item
      $('.media-item').bind('click.HandleSelection', mpxMediaHandler);

      // Load previous page
      $('#mpx-previous a').bind('click', function() {
        populateList(--current_page);
      });

      // Load next page
      $('#mpx-next a').bind('click', function() {
        populateList(++current_page);
      });


      // Check that file was selected.
      $('.mpx-submit').bind('click', function () {
        if ($("input[name='selected_file']").val() === '') {
          alert(Drupal.t('Please select an item.'));
          return false;
        }
      });

      // Filter list if mpxmedia_search is used.
      var timer = null;
      $('#edit-mpxmedia-search').keyup(function() {
        var value = $(this).val(),
            exp = new RegExp(value, 'i'),
            matchedItems = [];

        // Clear last timer, in case keyup came within 200ms of last one.
        window.clearTimeout(timer);

        // Only populate list 200ms after the last keystroke.
        timer = window.setTimeout(function() {
          timer = null;
          for (var i = 0; i < Drupal.settings.videos.form_list.length; ++i) {
            var item = Drupal.settings.videos.form_list[i];
            var isMatch = exp.test(item['#data']);
            if (isMatch) {
              matchedItems.push(item);
            }
          }

          // Keep reference to filtered list for reuse on pagination.
          // Generate pages and populate list.
          Drupal.settings.videos.parsed_form_list = matchedItems;
          generatePages(matchedItems);
          populateList();
        }, 200);
      });

      // Items per page select logic.
      $('#mpx-items-per-page-select').change(function() {
        var items = $('#edit-mpxmedia-search').val() ? Drupal.settings.videos.parsed_form_list : null;
        items_per_page = this.value;
        generatePages(items);
        populateList();
      });

      // Initial call to populateList()
      populateList();
    }
  };

}(jQuery));
